@@ -1,18 +1,6 @@
-VERSION = "2.0.0"
-
 from . import shapes as _
 
-from .grooves import (
-    BoxGroove, ConstrictedBoxGroove, UpsetBoxGroove, ConstrictedUpsetBoxGroove,
-    SquareGroove, DiamondGroove, GothicGroove,
-    RoundGroove, FalseRoundGroove,
-    CircularOvalGroove, FlatOvalGroove, SwedishOvalGroove, ConstrictedSwedishOvalGroove, Oval3RadiiGroove,
-    Oval3RadiiFlankedGroove, UpsetOvalGroove, ConstrictedCircularOvalGroove,
-    SplineGroove,
-    GenericElongationGroove,
-    FlatGroove,
-    HexagonalGroove
-)
+from .grooves import *
 from .transport import Transport
 from .roll_pass import RollPass, DeformationUnit, ThreeRollPass
 from .unit import Unit
@@ -24,6 +12,8 @@ from .hooks import Hook, HookHost, HookFunction, root_hooks
 from .disk_elements import DiskElementUnit
 from .config import Config, config
 
+VERSION = "2.0.1"
+
 root_hooks.update(
     {
         RollPass.roll_force,
